from enum import StrEnum


class Providers(StrEnum):
    OURA = "oura"
    FITBIT = "fitbit"
    GARMIN = "garmin"
    WHOOP = "whoop"
    STRAVA = "strava"
    RENPHO = "renpho"
    PELOTON = "peloton"
    WAHOO = "wahoo"
    ZWIFT = "zwift"
    FREESTYLE_LIBRE = "freestyle_libre"
    ABBOTT_LIBREVIEW = "abbott_libreview"
    TANDEM_SOURCE = "tandem_source"
    FREESTYLE_LIBRE_BLE = "freestyle_libre_ble"
    EIGHT_SLEEP = "eight_sleep"
    WITHINGS = "withings"
    APPLE_HEALTH_KIT = "apple_health_kit"
    MANUAL = "manual"
    IHEALTH = "ihealth"
    GOOGLE_FIT = "google_fit"
    BUERER_API = "beurer_api"
    BEURER_BLE = "beurer_ble"
    OMRON = "omron"
    OMRON_BLE = "omron_ble"
    ONETOUCH_BLE = "onetouch_ble"
    ACCUCHEK_BLE = "accuchek_ble"
    CONTOUR_BLE = "contour_ble"
    DEXCOM = "dexcom"
    DEXCOM_V3 = "dexcom_v3"
    HAMMERHEAD = "hammerhead"
    MY_FITNESS_PAL = "my_fitness_pal"
    HEALTH_CONNECT = "health_connect"
    SAMSUNG_HEALTH = "samsung_health"
    POLAR = "polar"
    CRONOMETER = "cronometer"
    KARDIA = "kardia"
    WHOOP_V2 = "whoop_v2"
    ULTRAHUMAN = "ultrahuman"
    MY_FITNESS_PAL_V2 = "my_fitness_pal_v2"
    MAP_MY_FITNESS = "map_my_fitness"
    RUNKEEPER = "runkeeper"


class Labs(StrEnum):
    AYUMETRIX = "ayumetrix"
    SPIRIPLEX = "spiriplex"
    USSL = "ussl"
    QUEST = "quest"
    SONORA_QUEST = "sonora_quest"
    LABCORP = "labcorp"
    BIOREFERENCE = "bioreference"
    BIOTEK = "us_biotek"
    MANUAL = "manual"
    SANOCARDIO = "sanocardio"
    IHD = "ihd"
    NEXUS = "nexus"
    MYUTI = "my_uti"
    CRL = "crl"
